@@ -6,7 +6,7 @@ use warnings;
 require DynaLoader;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 bootstrap FFI $VERSION;
 
@@ -163,7 +163,7 @@ the licensing of the FFI code.
 Please open any support tickets with this project's GitHub repository 
 here:
 
-L<https://github.com/plicease/FFI/issues>
+L<https://github.com/Perl5-FFI/FFI/issues>
 
 =head1 SEE ALSO
 
